@@ -1,5 +1,5 @@
 // WorkItem.cpp (Oclgrind)
-// Copyright (c) 2013-2016, James Price and Simon McIntosh-Smith,
+// Copyright (c) 2013-2019, James Price and Simon McIntosh-Smith,
 // University of Bristol. All rights reserved.`
 //
 // This program is provided under a three-clause BSD license. For full
@@ -528,19 +528,15 @@ void WorkItem::printExpression(string expr) const
     {
       baseValue = &*global;
 
-#if LLVM_VERSION >= 40
       llvm::SmallVector<llvm::DIGlobalVariableExpression*, 3> GVEs;
       global->getDebugInfo(GVEs);
       if (GVEs.size() == 0)
-#endif
       {
         cout << "global variable debug information not found";
         return;
       }
-#if LLVM_VERSION >= 40
       // TODO: Does it matter which GVE we pick?
       divar = llvm::dyn_cast<llvm::DIGlobalVariable>(GVEs[0]->getRawVariable());
-#endif
     }
   }
 
@@ -1661,11 +1657,7 @@ InterpreterCache::~InterpreterCache()
   for (constExprItr  = m_constExpressions.begin();
        constExprItr != m_constExpressions.end(); constExprItr++)
   {
-#if LLVM_VERSION < 50
-    delete constExprItr->second;
-#else
     constExprItr->second->deleteValue();
-#endif
   }
 }
 
