@@ -1,5 +1,5 @@
 // oclgrind.cpp (Oclgrind)
-// Copyright (c) 2013-2016, James Price and Simon McIntosh-Smith,
+// Copyright (c) 2013-2019, James Price and Simon McIntosh-Smith,
 // University of Bristol. All rights reserved.
 //
 // This program is provided under a three-clause BSD license. For full
@@ -212,6 +212,15 @@ static bool parseArguments(int argc, char *argv[])
     {
       setEnvironment("OCLGRIND_CHECK_API", "1");
     }
+    else if (!strcmp(argv[i], "--compute-units"))
+    {
+      if (++i >= argc)
+      {
+        cerr << "Missing argument to --compute-units" << endl;
+        return false;
+      }
+      setEnvironment("OCLGRIND_COMPUTE_UNITS", argv[i]);
+    }
     else if (!strcmp(argv[i], "--constant-mem-size"))
     {
       if (++i >= argc)
@@ -335,7 +344,7 @@ static bool parseArguments(int argc, char *argv[])
       cout << endl;
       cout << "Oclgrind " PACKAGE_VERSION << endl;
       cout << endl;
-      cout << "Copyright (c) 2013-2018" << endl;
+      cout << "Copyright (c) 2013-2019" << endl;
       cout << "James Price and Simon McIntosh-Smith, University of Bristol"
            << endl;
       cout << "https://github.com/jrprice/Oclgrind" << endl;
@@ -453,6 +462,8 @@ static void printUsage()
           "Additional options to pass to the OpenCL compiler" << endl
     << "  --check-api                  "
           "Report errors on API calls"  << endl
+    << "  --compute-units     UNITS    "
+          "Change the number of compute units reported" << endl
     << "  --constant-mem-size BYTES    "
           "Change the constant memory size of the device" << endl
     << "  --data-races                 "
