@@ -44,7 +44,7 @@ int main(int argc, char *argv[])
     exit(1);
   }
 
-  Context cl = createContext(KERNEL_SOURCE);
+  Context cl = createContext(KERNEL_SOURCE, "");
 
   kernel = clCreateKernel(cl.program, "vecadd", &err);
   checkError(err, "creating kernel");
